@@ -21,7 +21,10 @@ impl AliasGet {
         let config = Config::try_get()?;
         match config.get_all_aliases().get(&self.plugin) {
             Some(plugin) => match plugin.get(&self.alias) {
-                Some(alias) => Ok(miseprintln!("{}", alias)),
+                Some(alias) => {
+                    miseprintln!("{alias}");
+                    Ok(())
+                }
                 None => Err(eyre!("Unknown alias: {}", &self.alias)),
             },
             None => Err(eyre!("Unknown plugin: {}", &self.plugin)),
@@ -31,8 +34,8 @@ impl AliasGet {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
- $ <bold>mise alias get node lts-hydrogen</bold>
- 20.0.0
+   $ <bold>mise alias get node lts-hydrogen</bold>
+   20.0.0
 "#
 );
 
@@ -52,12 +55,12 @@ mod tests {
     #[test]
     fn test_alias_get_plugin_unknown() {
         let err = assert_cli_err!("alias", "get", "unknown", "unknown");
-        assert_display_snapshot!(err, @"Unknown plugin: unknown");
+        assert_snapshot!(err, @"Unknown plugin: unknown");
     }
 
     #[test]
     fn test_alias_get_alias_unknown() {
         let err = assert_cli_err!("alias", "get", "tiny", "unknown");
-        assert_display_snapshot!(err, @"Unknown alias: unknown");
+        assert_snapshot!(err, @"Unknown alias: unknown");
     }
 }
