@@ -21,14 +21,15 @@ pub struct AliasSet {
 impl AliasSet {
     pub fn run(self) -> Result<()> {
         let mut global_config = Config::get().global_config()?;
-        global_config.set_alias(&self.plugin, &self.alias, &self.value);
+        global_config.set_alias(&self.plugin, &self.alias, &self.value)?;
         global_config.save()
     }
 }
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise alias set node lts-hydrogen 18.0.0</bold>
+
+    $ <bold>mise alias set node lts-hydrogen 18.0.0</bold>
 "#
 );
 
