@@ -19,14 +19,15 @@ pub struct AliasUnset {
 impl AliasUnset {
     pub fn run(self) -> Result<()> {
         let mut global_config = Config::get().global_config()?;
-        global_config.remove_alias(&self.plugin, &self.alias);
+        global_config.remove_alias(&self.plugin, &self.alias)?;
         global_config.save()
     }
 }
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise alias unset node lts-hydrogen</bold>
+
+    $ <bold>mise alias unset node lts-hydrogen</bold>
 "#
 );
 
