@@ -1,4 +1,5 @@
 use clap::{Arg, ArgAction};
+use std::path::PathBuf;
 
 #[derive(Clone)]
 pub struct CdArg;
@@ -6,6 +7,7 @@ pub struct CdArg;
 impl CdArg {
     pub fn arg() -> Arg {
         Arg::new("cd")
+            .value_parser(clap::value_parser!(PathBuf))
             .short('C')
             .long("cd")
             .help("Change directory before running command")
