@@ -51,7 +51,7 @@ impl Env {
         for (k, v) in ts.env_with_path(config)? {
             let k = k.to_string();
             let v = v.to_string();
-            miseprint!("{}", shell.set_env(&k, &v));
+            miseprint!("{}", shell.set_env(&k, &v))?;
         }
         Ok(())
     }
@@ -59,10 +59,11 @@ impl Env {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>eval "$(mise env -s bash)"</bold>
-  $ <bold>eval "$(mise env -s zsh)"</bold>
-  $ <bold>mise env -s fish | source</bold>
-  $ <bold>execx($(mise env -s xonsh))</bold>
+
+    $ <bold>eval "$(mise env -s bash)"</bold>
+    $ <bold>eval "$(mise env -s zsh)"</bold>
+    $ <bold>mise env -s fish | source</bold>
+    $ <bold>execx($(mise env -s xonsh))</bold>
 "#
 );
 
