@@ -55,11 +55,12 @@ impl Latest {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise latest node@20</bold>  # get the latest version of node 20
-  20.0.0
 
-  $ <bold>mise latest node</bold>     # get the latest stable version of node
-  20.0.0
+    $ <bold>mise latest node@20</bold>  # get the latest version of node 20
+    20.0.0
+
+    $ <bold>mise latest node</bold>     # get the latest stable version of node
+    20.0.0
 "#
 );
 
@@ -78,7 +79,7 @@ mod tests {
     #[test]
     fn test_latest_system() {
         let err = assert_cli_err!("latest", "dummy@system");
-        assert_display_snapshot!(err);
+        assert_snapshot!(err);
     }
 
     #[test]
@@ -89,7 +90,7 @@ mod tests {
     #[test]
     fn test_latest_missing_plugin() {
         let stdout = assert_cli_err!("latest", "invalid_plugin");
-        assert_display_snapshot!(stdout);
+        assert_snapshot!(stdout);
     }
 
     #[test]
