@@ -18,7 +18,13 @@ use crate::forge::Forge;
 use crate::toolset::{ToolSource, ToolVersion, ToolsetBuilder};
 use crate::ui::table;
 
-/// List installed and/or currently selected tool versions
+/// List installed and active tool versions
+///
+/// This command lists tools that mise "knows about".
+/// These may be tools that are currently installed, or those
+/// that are in a config file (active) but may or may not be installed.
+///
+/// It's a useful command to get the current state of your tools.
 #[derive(Debug, clap::Args)]
 #[clap(visible_alias = "list", verbatim_doc_comment, after_long_help = AFTER_LONG_HELP)]
 pub struct Ls {
@@ -38,7 +44,7 @@ pub struct Ls {
     global: bool,
 
     /// Only show tool versions that are installed
-    /// Hides missing ones defined in .tool-versions/.mise.toml but not yet installed
+    /// (Hides tools defined in .tool-versions/.mise.toml but not installed)
     #[clap(long, short)]
     installed: bool,
 
@@ -46,7 +52,7 @@ pub struct Ls {
     #[clap(long, hide = true, conflicts_with = "json")]
     parseable: bool,
 
-    /// Output in json format
+    /// Output in JSON format
     #[clap(long, short = 'J', overrides_with = "parseable")]
     json: bool,
 
@@ -135,18 +141,19 @@ impl Ls {
     fn display_parseable(&self, runtimes: Vec<RuntimeRow>) -> Result<()> {
         warn!("The parseable output format is deprecated and will be removed in a future release.");
         warn!("Please use the regular output format instead which has been modified to be more easily parseable.");
-        runtimes
+        let tvs = runtimes
             .into_iter()
             .map(|(p, tv, _)| (p, tv))
             .filter(|(p, tv)| p.is_version_installed(tv))
-            .for_each(|(_, tv)| {
-                if self.plugin.is_some() {
-                    // only displaying 1 plugin so only show the version
-                    miseprintln!("{}", tv.version);
-                } else {
-                    miseprintln!("{} {}", &tv.forge, tv.version);
-                }
-            });
+            .map(|(_, tv)| tv);
+        for tv in tvs {
+            if self.plugin.is_some() {
+                // only displaying 1 plugin so only show the version
+                miseprintln!("{}", tv.version);
+            } else {
+                miseprintln!("{} {}", &tv.forge, tv.version);
+            }
+        }
         Ok(())
     }
 
@@ -232,6 +239,8 @@ struct JSONToolVersion {
     source: Option<IndexMap<String, String>>,
     #[serde(skip_serializing_if = "Option::is_none")]
     symlinked_to: Option<PathBuf>,
+    installed: bool,
+    active: bool,
 }
 
 type RuntimeRow = (Arc<dyn Forge>, ToolVersion, Option<ToolSource>);
@@ -269,12 +278,15 @@ impl Row {
 impl From<RuntimeRow> for JSONToolVersion {
     fn from(row: RuntimeRow) -> Self {
         let (p, tv, source) = row;
+        let vs: VersionStatus = (p.as_ref(), &tv, &source).into();
         JSONToolVersion {
             symlinked_to: p.symlink_path(&tv),
             install_path: tv.install_path(),
             version: tv.version,
             requested_version: source.as_ref().map(|_| tv.request.version()),
             source: source.map(|source| source.as_json()),
+            installed: !matches!(vs, VersionStatus::Missing(_)),
+            active: matches!(vs, VersionStatus::Active(_, _)),
         }
     }
 }
@@ -283,13 +295,13 @@ enum VersionStatus {
     Active(String, bool),
     Inactive(String),
     Missing(String),
-    Symlink(String, PathBuf, bool),
+    Symlink(String, bool),
 }
 
 impl From<(&dyn Forge, &ToolVersion, &Option<ToolSource>)> for VersionStatus {
     fn from((p, tv, source): (&dyn Forge, &ToolVersion, &Option<ToolSource>)) -> Self {
-        if let Some(symlink_path) = p.symlink_path(tv) {
-            VersionStatus::Symlink(tv.version.clone(), symlink_path, source.is_some())
+        if p.symlink_path(tv).is_some() {
+            VersionStatus::Symlink(tv.version.clone(), source.is_some())
         } else if !p.is_version_installed(tv) {
             VersionStatus::Missing(tv.version.clone())
         } else if source.is_some() {
@@ -322,7 +334,7 @@ impl Display for VersionStatus {
                 style(version).strikethrough().red(),
                 style("(missing)").red()
             ),
-            VersionStatus::Symlink(version, _, active) => {
+            VersionStatus::Symlink(version, active) => {
                 write!(
                     f,
                     "{} {}",
@@ -340,29 +352,30 @@ impl Display for VersionStatus {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise ls</bold>
-  node    20.0.0 ~/src/myapp/.tool-versions latest
-  python  3.11.0 ~/.tool-versions           3.10
-  python  3.10.0
 
-  $ <bold>mise ls --current</bold>
-  node    20.0.0 ~/src/myapp/.tool-versions 20
-  python  3.11.0 ~/.tool-versions           3.11.0
+    $ <bold>mise ls</bold>
+    node    20.0.0 ~/src/myapp/.tool-versions latest
+    python  3.11.0 ~/.tool-versions           3.10
+    python  3.10.0
 
-  $ <bold>mise ls --json</bold>
-  {
-    "node": [
-      {
-        "version": "20.0.0",
-        "install_path": "/Users/jdx/.mise/installs/node/20.0.0",
-        "source": {
-          "type": ".mise.toml",
-          "path": "/Users/jdx/.mise.toml"
+    $ <bold>mise ls --current</bold>
+    node    20.0.0 ~/src/myapp/.tool-versions 20
+    python  3.11.0 ~/.tool-versions           3.11.0
+
+    $ <bold>mise ls --json</bold>
+    {
+      "node": [
+        {
+          "version": "20.0.0",
+          "install_path": "/Users/jdx/.mise/installs/node/20.0.0",
+          "source": {
+            "type": ".mise.toml",
+            "path": "/Users/jdx/.mise.toml"
+          }
         }
-      }
-    ],
-    "python": [...]
-  }
+      ],
+      "python": [...]
+    }
 "#
 );
 
