@@ -32,8 +32,6 @@ mod ls_remote;
 mod outdated;
 mod plugins;
 mod prune;
-#[cfg(feature = "clap_complete")]
-mod render_completion;
 #[cfg(debug_assertions)]
 mod render_help;
 #[cfg(feature = "clap_mangen")]
@@ -45,11 +43,12 @@ mod set;
 mod settings;
 mod shell;
 mod sync;
-mod task;
+mod tasks;
 mod trust;
 mod uninstall;
 mod unset;
 mod upgrade;
+mod usage;
 mod r#use;
 pub mod version;
 mod watch;
@@ -93,20 +92,18 @@ pub enum Commands {
     Settings(settings::Settings),
     Shell(shell::Shell),
     Sync(sync::Sync),
-    Task(task::Task),
+    Tasks(tasks::Tasks),
     Trust(trust::Trust),
     Uninstall(uninstall::Uninstall),
-    Upgrade(upgrade::Upgrade),
     Unset(unset::Unset),
+    Upgrade(upgrade::Upgrade),
+    Usage(usage::Usage),
     Use(r#use::Use),
     Version(version::Version),
     Watch(watch::Watch),
     Where(r#where::Where),
     Which(which::Which),
 
-    #[cfg(feature = "clap_complete")]
-    RenderCompletion(render_completion::RenderCompletion),
-
     #[cfg(debug_assertions)]
     RenderHelp(render_help::RenderHelp),
 
@@ -150,20 +147,18 @@ impl Commands {
             Self::Settings(cmd) => cmd.run(),
             Self::Shell(cmd) => cmd.run(),
             Self::Sync(cmd) => cmd.run(),
-            Self::Task(cmd) => cmd.run(),
+            Self::Tasks(cmd) => cmd.run(),
             Self::Trust(cmd) => cmd.run(),
             Self::Uninstall(cmd) => cmd.run(),
             Self::Unset(cmd) => cmd.run(),
             Self::Upgrade(cmd) => cmd.run(),
+            Self::Usage(cmd) => cmd.run(),
             Self::Use(cmd) => cmd.run(),
             Self::Version(cmd) => cmd.run(),
             Self::Watch(cmd) => cmd.run(),
             Self::Where(cmd) => cmd.run(),
             Self::Which(cmd) => cmd.run(),
 
-            #[cfg(feature = "clap_complete")]
-            Self::RenderCompletion(cmd) => cmd.run(),
-
             #[cfg(debug_assertions)]
             Self::RenderHelp(cmd) => cmd.run(),
 
@@ -195,9 +190,9 @@ impl Cli {
     }
 
     pub fn run(args: &Vec<String>) -> Result<()> {
-        *crate::env::ARGS.write().unwrap() = args.clone();
+        crate::env::ARGS.write().unwrap().clone_from(args);
         shims::handle_shim()?;
-        version::print_version_if_requested(args);
+        version::print_version_if_requested(args)?;
 
         let matches = Self::command()
             .try_get_matches_from(args)
@@ -232,31 +227,32 @@ https://asdf-vm.com/"};
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise install node@20.0.0</bold>       Install a specific node version
-  $ <bold>mise install node@20</bold>           Install a version matching a prefix
-  $ <bold>mise install node</bold>              Install the node version defined in config
-  $ <bold>mise install</bold>                   Install all plugins/tools defined in config
+
+    $ <bold>mise install node@20.0.0</bold>       Install a specific node version
+    $ <bold>mise install node@20</bold>           Install a version matching a prefix
+    $ <bold>mise install node</bold>              Install the node version defined in config
+    $ <bold>mise install</bold>                   Install all plugins/tools defined in config
   
-  $ <bold>mise install cargo:ripgrep            Install something via cargo
-  $ <bold>mise install npm:prettier             Install something via npm
+    $ <bold>mise install cargo:ripgrep            Install something via cargo
+    $ <bold>mise install npm:prettier             Install something via npm
 
-  $ <bold>mise use node@20</bold>               Use node-20.x in current project
-  $ <bold>mise use -g node@20</bold>            Use node-20.x as default
-  $ <bold>mise use node@latest</bold>           Use latest node in current directory
-  $ <bold>mise use -g node@system</bold>        Use system node everywhere unless overridden
+    $ <bold>mise use node@20</bold>               Use node-20.x in current project
+    $ <bold>mise use -g node@20</bold>            Use node-20.x as default
+    $ <bold>mise use node@latest</bold>           Use latest node in current directory
+    $ <bold>mise use -g node@system</bold>        Use system node everywhere unless overridden
 
-  $ <bold>mise up --interactive</bold>          Show a menu to upgrade tools
+    $ <bold>mise up --interactive</bold>          Show a menu to upgrade tools
 
-  $ <bold>mise x -- npm install</bold>          `npm install` w/ config loaded into PATH
-  $ <bold>mise x node@20 -- node app.js</bold>  `node app.js` w/ config + node-20.x on PATH
+    $ <bold>mise x -- npm install</bold>          `npm install` w/ config loaded into PATH
+    $ <bold>mise x node@20 -- node app.js</bold>  `node app.js` w/ config + node-20.x on PATH
 
-  $ <bold>mise set NODE_ENV=production</bold>   Set NODE_ENV=production in config
+    $ <bold>mise set NODE_ENV=production</bold>   Set NODE_ENV=production in config
 
-  $ <bold>mise run build</bold>                 Run `build` task
-  $ <bold>mise watch build</bold>               Run `build` task repeatedly when files change
+    $ <bold>mise run build</bold>                 Run `build` tasks
+    $ <bold>mise watch build</bold>               Run `build` tasks repeatedly when files change
 
-  $ <bold>mise settings</bold>                  Show settings in use
-  $ <bold>mise settings set color 0</bold>      Disable color by modifying global config file
+    $ <bold>mise settings</bold>                  Show settings in use
+    $ <bold>mise settings set color 0</bold>      Disable color by modifying global config file
 "#
 );
 
