@@ -18,6 +18,10 @@ pub struct Outdated {
     /// If not specified, all tools in global and local configs will be shown
     #[clap(value_name = "TOOL@VERSION", verbatim_doc_comment)]
     pub tool: Vec<ToolArg>,
+
+    /// Output in JSON format
+    #[clap(short = 'J', long, verbatim_doc_comment)]
+    pub json: bool,
 }
 
 impl Outdated {
@@ -34,14 +38,16 @@ impl Outdated {
         let outdated = ts.list_outdated_versions();
         if outdated.is_empty() {
             info!("All tools are up to date");
+        } else if self.json {
+            self.display_json(outdated)?;
         } else {
-            self.display(outdated);
+            self.display(outdated)?;
         }
 
         Ok(())
     }
 
-    fn display(&self, outdated: OutputVec) {
+    fn display(&self, outdated: OutputVec) -> Result<()> {
         // TODO: make a generic table printer in src/ui/table
         let plugins = outdated.iter().map(|(t, _, _)| t.id()).collect::<Vec<_>>();
         let requests = outdated
@@ -102,6 +108,21 @@ impl Outdated {
                 latests[i]
             );
         }
+        Ok(())
+    }
+
+    fn display_json(&self, outdated: OutputVec) -> Result<()> {
+        let mut map = serde_json::Map::new();
+        for (t, tv, c) in outdated {
+            let mut inner = serde_json::Map::new();
+            inner.insert("requested".to_string(), tv.request.version().into());
+            inner.insert("current".to_string(), tv.version.clone().into());
+            inner.insert("latest".to_string(), c.into());
+            map.insert(t.id().to_string(), serde_json::Value::Object(inner));
+        }
+        let json = serde_json::Value::Object(map);
+        miseprintln!("{}", serde_json::to_string_pretty(&json)?);
+        Ok(())
     }
 }
 
@@ -109,19 +130,25 @@ type OutputVec = Vec<(Arc<dyn Forge>, ToolVersion, String)>;
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise outdated</bold>
-  Plugin  Requested  Current  Latest
-  python  3.11       3.11.0   3.11.1
-  node    20         20.0.0   20.1.0
 
-  $ <bold>mise outdated node</bold>
-  Plugin  Requested  Current  Latest
-  node    20         20.0.0   20.1.0
+    $ <bold>mise outdated</bold>
+    Plugin  Requested  Current  Latest
+    python  3.11       3.11.0   3.11.1
+    node    20         20.0.0   20.1.0
+
+    $ <bold>mise outdated node</bold>
+    Plugin  Requested  Current  Latest
+    node    20         20.0.0   20.1.0
+
+    $ <bold>mise outdated --json</bold>
+    {"python": {"requested": "3.11", "current": "3.11.0", "latest": "3.11.1"}, ...}
 "#
 );
 
 #[cfg(test)]
 mod tests {
+    use crate::test::change_installed_version;
+
     #[test]
     fn test_current() {
         assert_cli_snapshot!("outdated");
@@ -131,4 +158,11 @@ mod tests {
     fn test_current_with_runtimes() {
         assert_cli_snapshot!("outdated", "tiny");
     }
+
+    #[test]
+    fn test_current_json() {
+        change_installed_version("tiny", "3.1.0", "3.0.0");
+        assert_cli_snapshot!("outdated", "tiny", "--json");
+        change_installed_version("tiny", "3.0.0", "3.1.0");
+    }
 }
