@@ -10,7 +10,7 @@ use crate::ui::multi_progress_report::MultiProgressReport;
 ///
 /// note: this updates the plugin itself, not the runtime versions
 #[derive(Debug, clap::Args)]
-#[clap(verbatim_doc_comment, visible_alias = "upgrade", after_long_help = AFTER_LONG_HELP)]
+#[clap(verbatim_doc_comment, visible_aliases = ["up", "upgrade"], after_long_help = AFTER_LONG_HELP)]
 pub struct Update {
     /// Plugin(s) to update
     #[clap()]
@@ -61,9 +61,10 @@ impl Update {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise plugins update</bold>            # update all plugins
-  $ <bold>mise plugins update node</bold>       # update only node
-  $ <bold>mise plugins update node#beta</bold>  # specify a ref
+
+    $ <bold>mise plugins update</bold>            # update all plugins
+    $ <bold>mise plugins update node</bold>       # update only node
+    $ <bold>mise plugins update node#beta</bold>  # specify a ref
 "#
 );
 
