@@ -44,7 +44,7 @@ impl Prune {
         }
 
         for cf in config.get_tracked_config_files()?.values() {
-            let mut ts = cf.to_toolset().clone();
+            let mut ts = cf.to_toolset()?.clone();
             ts.resolve();
             for (_, tv) in ts.list_current_versions() {
                 to_delete.remove(&tv.to_string());
@@ -74,9 +74,10 @@ impl Prune {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise prune --dry-run</bold>
-  rm -rf ~/.local/share/mise/versions/node/20.0.0
-  rm -rf ~/.local/share/mise/versions/node/20.0.1
+
+    $ <bold>mise prune --dry-run</bold>
+    rm -rf ~/.local/share/mise/versions/node/20.0.0
+    rm -rf ~/.local/share/mise/versions/node/20.0.1
 "#
 );
 
