@@ -1,4 +1,4 @@
-use std::collections::BTreeMap;
+use std::collections::{BTreeMap, HashSet};
 use std::io::Write;
 use std::iter::once;
 use std::os::unix::prelude::ExitStatusExt;
@@ -12,6 +12,7 @@ use clap::ValueHint;
 use console::Color;
 use demand::{DemandOption, Select};
 use duct::IntoExecutablePath;
+use either::Either;
 use eyre::Result;
 use globwalk::GlobWalkerBuilder;
 use itertools::Itertools;
@@ -30,11 +31,11 @@ use crate::{env, file, ui};
 
 use super::args::ToolArg;
 
-/// [experimental] Run a task
+/// [experimental] Run a tasks
 ///
-/// This command will run a task, or multiple tasks in parallel.
+/// This command will run a tasks, or multiple tasks in parallel.
 /// Tasks may have dependencies on other tasks or on source files.
-/// If source is configured on a task, it will only run if the source
+/// If source is configured on a tasks, it will only run if the source
 /// files have changed.
 ///
 /// Tasks can be defined in .mise.toml or as standalone scripts.
@@ -47,7 +48,7 @@ use super::args::ToolArg;
 ///
 /// Alternatively, tasks can be defined as standalone scripts.
 /// These must be located in the `.mise/tasks` directory.
-/// The name of the script will be the name of the task.
+/// The name of the script will be the name of the tasks.
 ///
 ///     $ cat .mise/tasks/build<<EOF
 ///     #!/usr/bin/env bash
@@ -57,13 +58,13 @@ use super::args::ToolArg;
 #[derive(Debug, clap::Args)]
 #[clap(visible_alias = "r", verbatim_doc_comment, after_long_help = AFTER_LONG_HELP)]
 pub struct Run {
-    /// Task to run
+    /// Tasks to run
     /// Can specify multiple tasks by separating with `:::`
     /// e.g.: mise run task1 arg1 arg2 ::: task2 arg1 arg2
     #[clap(verbatim_doc_comment, default_value = "default")]
     pub task: String,
 
-    /// Arguments to pass to the task. Use ":::" to separate tasks.
+    /// Arguments to pass to the tasks. Use ":::" to separate tasks.
     #[clap(allow_hyphen_values = true)]
     pub args: Vec<String>,
 
@@ -71,15 +72,15 @@ pub struct Run {
     #[clap(short = 'C', long, value_hint = ValueHint::DirPath, long)]
     pub cd: Option<PathBuf>,
 
-    /// Don't actually run the task(s), just print them in order of execution
+    /// Don't actually run the tasks(s), just print them in order of execution
     #[clap(long, short = 'n', verbatim_doc_comment)]
     pub dry_run: bool,
 
-    /// Force the task to run even if outputs are up to date
+    /// Force the tasks to run even if outputs are up to date
     #[clap(long, short, verbatim_doc_comment)]
     pub force: bool,
 
-    /// Print stdout/stderr by line, prefixed with the task's label
+    /// Print stdout/stderr by line, prefixed with the tasks's label
     /// Defaults to true if --jobs > 1
     /// Configure with `task_output` config or `MISE_TASK_OUTPUT` env var
     #[clap(long, short, verbatim_doc_comment, overrides_with = "interleave")]
@@ -107,6 +108,10 @@ pub struct Run {
     #[clap(long, short, verbatim_doc_comment)]
     pub raw: bool,
 
+    /// Shows elapsed time after each tasks
+    #[clap(long, alias = "timing", verbatim_doc_comment)]
+    pub timings: bool,
+
     #[clap(skip)]
     pub is_linear: bool,
 }
@@ -115,7 +120,7 @@ impl Run {
     pub fn run(self) -> Result<()> {
         let config = Config::try_get()?;
         let settings = Settings::try_get()?;
-        settings.ensure_experimental()?;
+        settings.ensure_experimental("`mise run`")?;
         let task_list = self.get_task_lists(&config)?;
         self.parallelize_tasks(&config, task_list)
     }
@@ -135,15 +140,19 @@ impl Run {
             })
             .flat_map(|args| args.split_first().map(|(t, a)| (t.clone(), a.to_vec())))
             .map(|(t, args)| {
-                let tasks = config.tasks_with_aliases().get_matching(&t)?;
+                let tasks = config
+                    .tasks_with_aliases()?
+                    .get_matching(&t)?
+                    .into_iter()
+                    .cloned()
+                    .collect_vec();
                 if tasks.is_empty() {
-                    ensure!(t == "default", "no task {} found", style::ered(t));
+                    ensure!(t == "default", "no tasks {} found", style::ered(t));
 
                     Ok(vec![self.prompt_for_task(config)?])
                 } else {
                     Ok(tasks
-                        .iter()
-                        .cloned()
+                        .into_iter()
                         .map(|t| t.clone().with_args(args.to_vec()))
                         .collect())
                 }
@@ -160,19 +169,20 @@ impl Run {
         let mut env = ts.env_with_path(config)?;
         if let Some(root) = &config.project_root {
             env.insert("MISE_PROJECT_ROOT".into(), root.display().to_string());
-        }
-        if console::colors_enabled() {
-            env.insert("CLICOLOR_FORCE".into(), "1".into());
-            env.insert("FORCE_COLOR".into(), "1".into());
+            env.insert("root".into(), root.display().to_string());
         }
 
-        let tasks = Mutex::new(Deps::new(config, tasks)?);
-        self.is_linear = tasks.lock().unwrap().is_linear();
-
-        for task in tasks.lock().unwrap().all() {
+        let tasks = Deps::new(config, tasks)?;
+        for task in tasks.all() {
             self.validate_task(task)?;
         }
 
+        let num_tasks = tasks.all().count();
+        self.is_linear = tasks.is_linear();
+
+        let tasks = Mutex::new(tasks);
+        let timer = std::time::Instant::now();
+
         let pool = rayon::ThreadPoolBuilder::new()
             .num_threads(self.jobs() + 1)
             .build()?;
@@ -181,7 +191,7 @@ impl Run {
                 let t = task.clone();
                 s.spawn(|_| {
                     let task = t;
-                    trace!("running task: {task}");
+                    trace!("running tasks: {task}");
                     if let Err(err) = self.run_task(config, &env, &task) {
                         error!("{err}");
                         exit(1);
@@ -195,6 +205,12 @@ impl Run {
                 run(&task);
             }
         });
+
+        if self.timings && num_tasks > 1 {
+            let msg = format!("finished in {}", format_duration(timer.elapsed()));
+            info!("{}", style::edim(msg));
+        };
+
         Ok(())
     }
 
@@ -205,12 +221,25 @@ impl Run {
             return Ok(());
         }
 
+        let string_env = task.env.iter().filter_map(|(k, v)| match &v.0 {
+            Either::Left(v) => Some((k, v)),
+            _ => None,
+        });
+        let rm_env = task
+            .env
+            .iter()
+            .filter(|(_, v)| v.0 == Either::Right(false))
+            .map(|(k, _)| k)
+            .collect::<HashSet<_>>();
         let env: BTreeMap<String, String> = env
             .iter()
-            .chain(task.env.iter())
+            .chain(string_env)
+            .filter(|(k, _)| !rm_env.contains(k))
             .map(|(k, v)| (k.clone(), v.clone()))
             .collect();
 
+        let timer = std::time::Instant::now();
+
         if let Some(file) = &task.file {
             self.exec_file(file, task, &env, &prefix)?;
         } else {
@@ -223,6 +252,14 @@ impl Run {
             }
         }
 
+        if self.timings {
+            miseprintln!(
+                "{} finished in {}",
+                prefix,
+                format_duration(timer.elapsed())
+            );
+        }
+
         self.save_checksum(task)?;
 
         Ok(())
@@ -236,19 +273,23 @@ impl Run {
         env: &BTreeMap<String, String>,
         prefix: &str,
     ) -> Result<()> {
-        let script = format!("{} {}", script, shell_words::join(args));
+        let script = script.trim_start();
         let cmd = style::ebold(format!("$ {script}")).bright().to_string();
         info_unprefix_trunc!("{prefix} {cmd}");
 
-        if env::var("MISE_TASK_SCRIPT_FILE").is_ok() {
-            let mut tmp = tempfile::NamedTempFile::new()?;
-            let args = once(tmp.path().display().to_string())
-                .chain(args.iter().cloned())
-                .collect_vec();
-            writeln!(tmp, "{}", script.trim())?;
-            self.exec("sh", &args, task, env, prefix)
+        if script.starts_with("#!") {
+            let dir = tempfile::tempdir()?;
+            let file = dir.path().join("script");
+            let mut tmp = std::fs::File::create(&file)?;
+            tmp.write_all(script.as_bytes())?;
+            tmp.flush()?;
+            drop(tmp);
+            file::make_executable(&file)?;
+            let filename = file.display().to_string();
+            self.exec(&filename, args, task, env, prefix)
         } else {
-            let args = vec!["-c".to_string(), script.trim().to_string()];
+            let script = format!("{} {}", script, shell_words::join(args));
+            let args = vec!["-c".to_string(), script];
             self.exec("sh", &args, task, env, prefix)
         }
     }
@@ -344,24 +385,23 @@ impl Run {
     }
 
     fn prompt_for_task(&self, config: &Config) -> Result<Task> {
-        let tasks = config.tasks();
+        let tasks = config.tasks()?;
         ensure!(
             !tasks.is_empty(),
             "no tasks defined. see {url}",
             url = style::eunderline("https://mise.jdx.dev/tasks/")
         );
-        let task_names = tasks.keys().sorted().collect_vec();
         let mut s = Select::new("Tasks")
-            .description("Select a task to run")
+            .description("Select a tasks to run")
             .filterable(true);
-        for name in task_names {
+        for name in tasks.keys() {
             s = s.option(DemandOption::new(name));
         }
-        let _ = ctrlc::handle_ctrlc()?;
+        let _ctrlc = ctrlc::handle_ctrlc()?;
         let name = s.run()?;
         match tasks.get(name) {
-            Some(task) => Ok(task.clone()),
-            None => bail!("no task {} found", style::ered(name)),
+            Some(task) => Ok((*task).clone()),
+            None => bail!("no tasks {} found", style::ered(name)),
         }
     }
 
@@ -466,6 +506,9 @@ fn last_modified_glob_match(
     root: impl AsRef<Path>,
     patterns: &[&String],
 ) -> Result<Option<SystemTime>> {
+    if patterns.is_empty() {
+        return Ok(None);
+    }
     let files = GlobWalkerBuilder::from_patterns(root, patterns)
         .follow_links(true)
         .build()?
@@ -491,22 +534,23 @@ fn last_modified_file(files: impl IntoIterator<Item = PathBuf>) -> Result<Option
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise run lint</bold>
-  Runs the "lint" task. This needs to either be defined in .mise.toml
-  or as a standalone script. See the project README for more information.
 
-  $ <bold>mise run build --force</bold>
-  Forces the "build" task to run even if its sources are up-to-date.
+    # Runs the "lint" tasks. This needs to either be defined in .mise.toml
+    # or as a standalone script. See the project README for more information.
+    $ <bold>mise run lint</bold>
 
-  $ <bold>mise run test --raw</bold>
-  Runs "test" with stdin/stdout/stderr all connected to the current terminal.
-  This forces `--jobs=1` to prevent interleaving of output.
+    # Forces the "build" tasks to run even if its sources are up-to-date.
+    $ <bold>mise run build --force</bold>
 
-  $ <bold>mise run lint ::: test ::: check</bold>
-  Runs the "lint", "test", and "check" tasks in parallel.
+    # Run "test" with stdin/stdout/stderr all connected to the current terminal.
+    # This forces `--jobs=1` to prevent interleaving of output.
+    $ <bold>mise run test --raw</bold>
 
-  $ <bold>mise task cmd1 arg1 arg2 ::: cmd2 arg1 arg2</bold>
-  Execute multiple tasks each with their own arguments.
+    # Runs the "lint", "test", and "check" tasks in parallel.
+    $ <bold>mise run lint ::: test ::: check</bold>
+
+    # Execute multiple tasks each with their own arguments.
+    $ <bold>mise tasks cmd1 arg1 arg2 ::: cmd2 arg1 arg2</bold>
 "#
 );
 
@@ -531,6 +575,15 @@ fn get_color() -> Color {
     static COLOR_IDX: AtomicUsize = AtomicUsize::new(0);
     COLORS[COLOR_IDX.fetch_add(1, Ordering::Relaxed) % COLORS.len()]
 }
+
+fn format_duration(dur: std::time::Duration) -> String {
+    if dur < std::time::Duration::from_secs(1) {
+        format!("{:.0?}", dur)
+    } else {
+        format!("{:.2?}", dur)
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use crate::file;
