@@ -1,5 +1,5 @@
 use eyre::Result;
-use toml_edit::Document;
+use toml_edit::DocumentMut;
 
 use crate::{env, file};
 
@@ -17,7 +17,7 @@ impl SettingsUnset {
     pub fn run(self) -> Result<()> {
         let path = env::MISE_CONFIG_DIR.join("config.toml");
         let raw = file::read_to_string(&path)?;
-        let mut settings: Document = raw.parse()?;
+        let mut settings: DocumentMut = raw.parse()?;
         settings.remove(&self.setting);
         file::write(&path, settings.to_string())
     }
@@ -25,7 +25,8 @@ impl SettingsUnset {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise settings unset legacy_version_file</bold>
+
+    $ <bold>mise settings unset legacy_version_file</bold>
 "#
 );
 
@@ -50,6 +51,12 @@ mod tests {
         disable_default_shorthands = false
         disable_tools = []
         experimental = true
+        go_default_packages_file = "~/.default-go-packages"
+        go_download_mirror = "https://dl.google.com/go"
+        go_repo = "https://github.com/golang/go"
+        go_set_gopath = false
+        go_set_goroot = true
+        go_skip_checksum = false
         jobs = 2
         legacy_version_file = true
         legacy_version_file_disable_tools = []
@@ -59,20 +66,17 @@ mod tests {
         plugin_autoupdate_last_check_duration = "20m"
         python_compile = false
         python_default_packages_file = "~/.default-python-packages"
-        python_patch_url = null
-        python_patches_directory = null
-        python_precompiled_arch = null
-        python_precompiled_os = null
         python_pyenv_repo = "https://github.com/pyenv/pyenv.git"
-        python_venv_auto_create = false
         quiet = false
         raw = false
-        shorthands_file = null
-        status = {"missing_tools":true,"show_env":false,"show_tools":false}
-        task_output = null
         trusted_config_paths = []
         verbose = true
         yes = true
+
+        [status]
+        missing_tools = "if_other_versions_installed"
+        show_env = false
+        show_tools = false
         "###);
 
         reset_config();
