@@ -3,12 +3,17 @@ use console::style;
 
 use crate::cli::args::ToolArg;
 use crate::config::Config;
+use crate::env;
 use crate::shell::get_shell;
 use crate::toolset::{InstallOptions, ToolSource, ToolsetBuilder};
 
-/// Sets a tool version for the current shell session
+/// Sets a tool version for the current session
 ///
 /// Only works in a session where mise is already activated.
+///
+/// This works by setting environment variables for the current shell session
+/// such as `MISE_NODE_VERSION=20` which is "eval"ed as a shell function created
+/// by `mise activate`.
 #[derive(Debug, clap::Args)]
 #[clap(verbatim_doc_comment, visible_alias = "sh", after_long_help = AFTER_LONG_HELP)]
 pub struct Shell {
@@ -34,7 +39,7 @@ pub struct Shell {
 impl Shell {
     pub fn run(self) -> Result<()> {
         let config = Config::try_get()?;
-        if !config.is_activated() {
+        if !env::is_activated() {
             err_inactive()?;
         }
 
@@ -79,9 +84,10 @@ fn err_inactive() -> Result<()> {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  $ <bold>mise shell node@20</bold>
-  $ <bold>node -v</bold>
-  v20.0.0
+
+    $ <bold>mise shell node@20</bold>
+    $ <bold>node -v</bold>
+    v20.0.0
 "#
 );
 
@@ -92,7 +98,7 @@ mod tests {
     #[test]
     fn test_shell() {
         let err = assert_cli_err!("shell", "tiny@1.0.1");
-        assert_display_snapshot!(err);
+        assert_snapshot!(err);
         env::set_var("__MISE_DIFF", "");
         env::set_var("MISE_SHELL", "zsh");
         assert_cli_snapshot!("shell", "tiny@1.0.1");
