@@ -15,7 +15,7 @@ use crate::toolset::{InstallOptions, ToolSource, ToolVersion, ToolVersionRequest
 use crate::ui::multi_progress_report::MultiProgressReport;
 use crate::{env, file, forge};
 
-/// Change the active version of a tool locally or globally.
+/// Install tool version and add it to config
 ///
 /// This will install the tool if it is not already installed.
 /// By default, this will use an `.mise.toml` file in the current directory.
@@ -122,17 +122,17 @@ impl Use {
                     }
                 })
                 .collect();
-            cf.replace_versions(fa, &versions);
+            cf.replace_versions(fa, &versions)?;
         }
 
         if self.global {
             self.warn_if_hidden(&config, cf.get_path());
         }
         for plugin_name in &self.remove {
-            cf.remove_plugin(plugin_name);
+            cf.remove_plugin(plugin_name)?;
         }
         cf.save()?;
-        self.render_success_message(cf.as_ref(), &versions);
+        self.render_success_message(cf.as_ref(), &versions)?;
         Ok(())
     }
 
@@ -168,7 +168,7 @@ impl Use {
         }
     }
 
-    fn render_success_message(&self, cf: &dyn ConfigFile, versions: &[ToolVersion]) {
+    fn render_success_message(&self, cf: &dyn ConfigFile, versions: &[ToolVersion]) -> Result<()> {
         let path = display_path(cf.get_path());
         let tools = versions.iter().map(|t| t.style()).join(", ");
         miseprintln!(
@@ -176,6 +176,7 @@ impl Use {
             style("mise").green(),
             style(path).cyan().for_stderr(),
         );
+        Ok(())
     }
 }
 
@@ -199,19 +200,20 @@ fn config_file_from_dir(p: &Path) -> PathBuf {
 
 static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
-  # set the current version of node to 20.x in .mise.toml of current directory
-  # will write the fuzzy version (e.g.: 20)
-  $ <bold>mise use node@20</bold>
 
-  # set the current version of node to 20.x in ~/.config/mise/config.toml
-  # will write the precise version (e.g.: 20.0.0)
-  $ <bold>mise use -g --pin node@20</bold>
+    # set the current version of node to 20.x in .mise.toml of current directory
+    # will write the fuzzy version (e.g.: 20)
+    $ <bold>mise use node@20</bold>
 
-  # sets .mise.local.toml (which is intended not to be committed to a project)
-  $ <bold>mise use --env local node@20</bold>
+    # set the current version of node to 20.x in ~/.config/mise/config.toml
+    # will write the precise version (e.g.: 20.0.0)
+    $ <bold>mise use -g --pin node@20</bold>
 
-  # sets .mise.staging.toml (which is used if MISE_ENV=staging)
-  $ <bold>mise use --env staging node@20</bold>
+    # sets .mise.local.toml (which is intended not to be committed to a project)
+    $ <bold>mise use --env local node@20</bold>
+
+    # sets .mise.staging.toml (which is used if MISE_ENV=staging)
+    $ <bold>mise use --env staging node@20</bold>
 "#
 );
 
@@ -264,13 +266,31 @@ mod tests {
     fn test_use_global() {
         let cf_path = dirs::CONFIG.join("config.toml");
         let orig = file::read_to_string(&cf_path).unwrap();
-        let _ = file::remove_file(&cf_path);
 
         assert_cli_snapshot!("use", "-g", "tiny@2", @r###"
         mise ~/config/config.toml tools: tiny@2.1.0
         mise tiny is defined in ~/cwd/.test-tool-versions which overrides the global config (~/config/config.toml)
         "###);
         assert_snapshot!(file::read_to_string(&cf_path).unwrap(), @r###"
+        [env]
+        TEST_ENV_VAR = 'test-123'
+
+        [alias.tiny]
+        "my/alias" = '3.0'
+
+        [tasks.configtask]
+        run = 'echo "configtask:"'
+        [tasks.lint]
+        run = 'echo "linting!"'
+        [tasks.test]
+        run = 'echo "testing!"'
+        [settings]
+        always_keep_download= true
+        always_keep_install= true
+        legacy_version_file= true
+        plugin_autoupdate_last_check_duration = "20m"
+        jobs = 2
+
         [tools]
         tiny = "2"
         "###);
