@@ -1,4 +1,3 @@
-use std::string::ToString;
 use std::time::Duration;
 
 use console::style;
@@ -43,29 +42,31 @@ pub static V: Lazy<Versioning> = Lazy::new(|| Versioning::new(env!("CARGO_PKG_VE
 
 impl Version {
     pub fn run(self) -> Result<()> {
-        show_version();
+        show_version()?;
         Ok(())
     }
 }
 
-pub fn print_version_if_requested(args: &[String]) {
+pub fn print_version_if_requested(args: &[String]) -> std::io::Result<()> {
     if args.len() == 2 && *env::MISE_BIN_NAME == "mise" {
         let cmd = &args[1].to_lowercase();
         if cmd == "version" || cmd == "-v" || cmd == "--version" {
-            show_version();
+            show_version()?;
             std::process::exit(0);
         }
     }
     debug!("Version: {}", *VERSION);
+    Ok(())
 }
 
-fn show_version() {
+fn show_version() -> std::io::Result<()> {
     miseprintln!("{}", *VERSION);
     show_latest();
+    Ok(())
 }
 
 fn show_latest() {
-    if *env::CI {
+    if ci_info::is_ci() && !cfg!(test) {
         return;
     }
     if let Some(latest) = check_for_new_version(duration::DAILY) {
