@@ -1,10 +1,9 @@
-use std::default::Default;
 use std::path::{Path, PathBuf};
 
 use eyre::Result;
 
 use crate::cli::args::ForgeArg;
-use crate::config::config_file::{ConfigFile, ConfigFileType};
+use crate::config::config_file::ConfigFile;
 use crate::forge::ForgeList;
 use crate::toolset::{ToolSource, ToolVersionRequest, Toolset};
 
@@ -33,19 +32,15 @@ impl LegacyVersionFile {
 }
 
 impl ConfigFile for LegacyVersionFile {
-    fn get_type(&self) -> ConfigFileType {
-        ConfigFileType::LegacyVersion
-    }
-
     fn get_path(&self) -> &Path {
         self.path.as_path()
     }
 
-    fn remove_plugin(&mut self, _fa: &ForgeArg) {
+    fn remove_plugin(&mut self, _fa: &ForgeArg) -> Result<()> {
         unimplemented!()
     }
 
-    fn replace_versions(&mut self, _plugin_name: &ForgeArg, _versions: &[String]) {
+    fn replace_versions(&mut self, _plugin_name: &ForgeArg, _versions: &[String]) -> Result<()> {
         unimplemented!()
     }
 
@@ -53,11 +48,11 @@ impl ConfigFile for LegacyVersionFile {
         unimplemented!()
     }
 
-    fn dump(&self) -> String {
+    fn dump(&self) -> Result<String> {
         unimplemented!()
     }
 
-    fn to_toolset(&self) -> &Toolset {
-        &self.toolset
+    fn to_toolset(&self) -> Result<Toolset> {
+        Ok(self.toolset.clone())
     }
 }
