@@ -7,6 +7,7 @@ use std::sync::Mutex;
 
 use eyre::Result;
 use once_cell::sync::Lazy;
+use serde_derive::Deserialize;
 use versions::Versioning;
 
 use tool_versions::ToolVersions;
@@ -32,11 +33,10 @@ pub mod tool_versions;
 pub enum ConfigFileType {
     MiseToml,
     ToolVersions,
-    LegacyVersion,
+    // LegacyVersion,
 }
 
 pub trait ConfigFile: Debug + Send + Sync {
-    fn get_type(&self) -> ConfigFileType;
     fn get_path(&self) -> &Path;
     fn min_version(&self) -> &Option<Versioning> {
         &None
@@ -69,20 +69,24 @@ pub trait ConfigFile: Debug + Send + Sync {
     fn tasks(&self) -> Vec<&Task> {
         Default::default()
     }
-    fn remove_plugin(&mut self, _fa: &ForgeArg);
-    fn replace_versions(&mut self, fa: &ForgeArg, versions: &[String]);
+    fn remove_plugin(&mut self, _fa: &ForgeArg) -> Result<()>;
+    fn replace_versions(&mut self, fa: &ForgeArg, versions: &[String]) -> Result<()>;
     fn save(&self) -> Result<()>;
-    fn dump(&self) -> String;
-    fn to_toolset(&self) -> &Toolset;
+    fn dump(&self) -> Result<String>;
+    fn to_toolset(&self) -> Result<Toolset>;
     fn aliases(&self) -> AliasMap {
         Default::default()
     }
+    fn task_config(&self) -> &TaskConfig {
+        static DEFAULT_TASK_CONFIG: Lazy<TaskConfig> = Lazy::new(TaskConfig::default);
+        &DEFAULT_TASK_CONFIG
+    }
 }
 
 impl dyn ConfigFile {
     pub fn add_runtimes(&mut self, tools: &[ToolArg], pin: bool) -> Result<()> {
         // TODO: this has become a complete mess and could probably be greatly simplified
-        let mut ts = self.to_toolset().to_owned();
+        let mut ts = self.to_toolset()?.to_owned();
         ts.resolve();
         let mut plugins_to_update = HashMap::new();
         for ta in tools {
@@ -114,7 +118,7 @@ impl dyn ConfigFile {
                     }
                 })
                 .collect::<Result<Vec<_>>>()?;
-            self.replace_versions(&fa, &versions);
+            self.replace_versions(&fa, &versions)?;
         }
 
         Ok(())
@@ -128,7 +132,7 @@ impl dyn ConfigFile {
         if runtimes.len() == 1 && runtimes[0].tvr.is_none() {
             let fa = &runtimes[0].forge;
             let tvl = self
-                .to_toolset()
+                .to_toolset()?
                 .versions
                 .get(fa)
                 .ok_or_else(|| {
@@ -217,9 +221,6 @@ pub fn is_trusted(path: &Path) -> bool {
             return true;
         }
     }
-    if !trust_path(path).exists() {
-        return false;
-    }
     if settings.paranoid {
         let trusted = trust_file_hash(path).unwrap_or_else(|e| {
             warn!("trust_file_hash: {e}");
@@ -228,6 +229,10 @@ pub fn is_trusted(path: &Path) -> bool {
         if !trusted {
             return false;
         }
+    } else if !(trust_path(path).exists() || ci_info::is_ci() && !cfg!(test)) {
+        // the file isn't trusted, and we're not on a CI system where we generally assume we can
+        // trust config files
+        return false;
     }
     cached.insert(path.to_path_buf());
     true
@@ -308,7 +313,7 @@ fn detect_config_file_type(path: &Path) -> Option<ConfigFileType> {
 
 impl Display for dyn ConfigFile {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        let toolset = self.to_toolset().to_string();
+        let toolset = self.to_toolset().unwrap().to_string();
         write!(f, "{}: {toolset}", &display_path(self.get_path()))
     }
 }
@@ -327,6 +332,11 @@ impl Hash for dyn ConfigFile {
     }
 }
 
+#[derive(Clone, Debug, Default, Deserialize)]
+pub struct TaskConfig {
+    pub includes: Option<Vec<PathBuf>>,
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
