@@ -9,7 +9,7 @@ use tera::Context;
 
 use crate::cli::args::ForgeArg;
 use crate::config::config_file;
-use crate::config::config_file::{ConfigFile, ConfigFileType};
+use crate::config::config_file::ConfigFile;
 use crate::file;
 use crate::file::display_path;
 use crate::tera::{get_tera, BASE_CONTEXT};
@@ -151,31 +151,29 @@ impl Display for ToolVersions {
 }
 
 impl ConfigFile for ToolVersions {
-    fn get_type(&self) -> ConfigFileType {
-        ConfigFileType::ToolVersions
-    }
-
     fn get_path(&self) -> &Path {
         self.path.as_path()
     }
 
-    fn remove_plugin(&mut self, fa: &ForgeArg) {
-        self.plugins.remove(fa);
+    fn remove_plugin(&mut self, fa: &ForgeArg) -> Result<()> {
+        self.plugins.shift_remove(fa);
+        Ok(())
     }
 
-    fn replace_versions(&mut self, fa: &ForgeArg, versions: &[String]) {
+    fn replace_versions(&mut self, fa: &ForgeArg, versions: &[String]) -> eyre::Result<()> {
         self.get_or_create_plugin(fa).versions.clear();
         for version in versions {
             self.add_version(fa, version);
         }
+        Ok(())
     }
 
     fn save(&self) -> Result<()> {
-        let s = self.dump();
+        let s = self.dump()?;
         file::write(&self.path, s)
     }
 
-    fn dump(&self) -> String {
+    fn dump(&self) -> eyre::Result<String> {
         let mut s = self.pre.clone();
 
         let max_plugin_len = self
@@ -195,11 +193,11 @@ impl ConfigFile for ToolVersions {
             s.push_str(&format!("{} {}{}", plugin, tv.versions.join(" "), tv.post));
         }
 
-        s.trim_end().to_string() + "\n"
+        Ok(s.trim_end().to_string() + "\n")
     }
 
-    fn to_toolset(&self) -> &Toolset {
-        &self.toolset
+    fn to_toolset(&self) -> Result<Toolset> {
+        Ok(self.toolset.clone())
     }
 }
 
@@ -224,7 +222,7 @@ pub(crate) mod tests {
             tv.path,
             env::current_dir().unwrap().join(".test-tool-versions")
         );
-        assert_display_snapshot!(tv, @"ToolVersions(~/cwd/.test-tool-versions): tiny@3");
+        assert_snapshot!(tv, @"ToolVersions(~/cwd/.test-tool-versions): tiny@3");
     }
 
     #[test]
@@ -238,7 +236,7 @@ pub(crate) mod tests {
         "};
         let path = env::current_dir().unwrap().join(".test-tool-versions");
         let tv = ToolVersions::parse_str(orig, path).unwrap();
-        assert_eq!(tv.dump(), orig);
+        assert_eq!(tv.dump().unwrap(), orig);
     }
 
     #[test]
@@ -248,7 +246,7 @@ pub(crate) mod tests {
         "};
         let path = env::current_dir().unwrap().join(".test-tool-versions");
         let tv = ToolVersions::parse_str(orig, path).unwrap();
-        assert_snapshot!(tv.dump(), @r###"
+        assert_snapshot!(tv.dump().unwrap(), @r###"
         ruby 3.0.5
         "###);
     }
@@ -263,7 +261,7 @@ pub(crate) mod tests {
         assert_cli!("trust", path.to_string_lossy());
         let tv = ToolVersions::parse_str(orig, path.clone()).unwrap();
         assert_cli!("trust", "--untrust", path.to_string_lossy());
-        assert_snapshot!(tv.dump(), @r###"
+        assert_snapshot!(tv.dump().unwrap(), @r###"
         ruby   3.0.5
         python 3.11.0
         "###);
@@ -276,6 +274,6 @@ pub(crate) mod tests {
         "};
         let path = env::current_dir().unwrap().join(".test-tool-versions");
         let tv = ToolVersions::parse_str(orig, path).unwrap();
-        assert_display_snapshot!(tv.to_toolset(), @"ruby@3.0.5 ruby@3.1");
+        assert_snapshot!(tv.to_toolset().unwrap(), @"ruby@3.0.5 ruby@3.1");
     }
 }
