@@ -2,9 +2,8 @@ use std::collections::{BTreeMap, BTreeSet, HashMap};
 use std::fmt::{Debug, Formatter};
 use std::iter::once;
 use std::path::{Path, PathBuf};
-use std::sync::{Arc, RwLock};
+use std::sync::{Arc, OnceLock, RwLock};
 
-use either::Either;
 use eyre::{Context, Result};
 use indexmap::IndexMap;
 use itertools::Itertools;
@@ -43,11 +42,10 @@ pub struct Config {
     pub project_root: Option<PathBuf>,
     env: OnceCell<EnvResults>,
     env_with_sources: OnceCell<EnvWithSources>,
-    all_aliases: OnceCell<AliasMap>,
+    all_aliases: OnceLock<AliasMap>,
     repo_urls: HashMap<String, String>,
-    shorthands: OnceCell<HashMap<String, String>>,
-    tasks: OnceCell<HashMap<String, Task>>,
-    tasks_with_aliases: OnceCell<HashMap<String, Task>>,
+    shorthands: OnceLock<HashMap<String, String>>,
+    tasks: OnceCell<BTreeMap<String, Task>>,
 }
 
 static CONFIG: RwLock<Option<Arc<Config>>> = RwLock::new(None);
@@ -83,10 +81,9 @@ impl Config {
             env: OnceCell::new(),
             env_with_sources: OnceCell::new(),
             aliases: load_aliases(&config_files),
-            all_aliases: OnceCell::new(),
-            shorthands: OnceCell::new(),
+            all_aliases: OnceLock::new(),
+            shorthands: OnceLock::new(),
             tasks: OnceCell::new(),
-            tasks_with_aliases: OnceCell::new(),
             project_root: get_project_root(&config_files),
             config_files,
             repo_urls,
@@ -109,8 +106,8 @@ impl Config {
         self.env_with_sources.get_or_try_init(|| {
             let mut env = self.env_results()?.env.clone();
             let settings = Settings::get();
-            if let Some(env_file) = &settings.env_file {
-                match dotenvy::from_filename_iter(env_file) {
+            for env_file in settings.env_files() {
+                match dotenvy::from_path_iter(&env_file) {
                     Ok(iter) => {
                         for item in iter {
                             let (k, v) = item.unwrap_or_else(|err| {
@@ -149,22 +146,22 @@ impl Config {
         self.all_aliases.get_or_init(|| self.load_all_aliases())
     }
 
-    pub fn tasks(&self) -> &HashMap<String, Task> {
-        self.tasks.get_or_init(|| {
-            self.load_all_tasks()
-                .into_iter()
-                .filter(|(n, t)| *n == t.name)
-                .collect()
-        })
+    pub fn tasks(&self) -> Result<&BTreeMap<String, Task>> {
+        self.tasks.get_or_try_init(|| self.load_all_tasks())
     }
 
-    pub fn tasks_with_aliases(&self) -> &HashMap<String, Task> {
-        self.tasks_with_aliases
-            .get_or_init(|| self.load_all_tasks())
-    }
-
-    pub fn is_activated(&self) -> bool {
-        env::var("__MISE_DIFF").is_ok()
+    pub fn tasks_with_aliases(&self) -> Result<BTreeMap<String, &Task>> {
+        Ok(self
+            .tasks()?
+            .iter()
+            .flat_map(|(_, t)| {
+                t.aliases
+                    .iter()
+                    .map(|a| (a.to_string(), t))
+                    .chain(once((t.name.clone(), t)))
+                    .collect::<Vec<_>>()
+            })
+            .collect())
     }
 
     pub fn resolve_alias(&self, forge: &dyn Forge, v: &str) -> Result<String> {
@@ -209,53 +206,114 @@ impl Config {
         aliases
     }
 
-    pub fn load_all_tasks(&self) -> HashMap<String, Task> {
-        self.config_files
-            .values()
-            .collect_vec()
-            .into_par_iter()
-            .flat_map(|cf| {
-                match cf.project_root() {
-                    Some(pr) => vec![
-                        pr.join(".mise").join("tasks"),
-                        pr.join(".config").join("mise").join("tasks"),
-                    ],
-                    None => vec![],
+    pub fn load_all_tasks(&self) -> Result<BTreeMap<String, Task>> {
+        Ok(file::all_dirs()?
+            .into_iter()
+            .filter(|d| {
+                if cfg!(test) {
+                    d.starts_with(*dirs::HOME)
+                } else {
+                    true
                 }
-                .into_par_iter()
-                .flat_map(|dir| {
-                    file::recursive_ls(&dir).map_err(|err| warn!("load_all_tasks: {err}"))
-                })
-                .flatten()
-                .map(Either::Right)
-                .chain(rayon::iter::once(Either::Left(cf)))
             })
-            .collect::<Vec<Either<&Box<dyn ConfigFile>, PathBuf>>>()
-            .into_iter()
-            .rev()
-            .unique()
             .collect_vec()
             .into_par_iter()
-            .flat_map(|either| match either {
-                Either::Left(cf) => cf.tasks().into_iter().cloned().collect(),
-                Either::Right(path) => match Task::from_path(&path) {
-                    Ok(task) => vec![task],
-                    Err(err) => {
-                        warn!("Error loading task {}: {err:#}", display_path(&path));
-                        vec![]
-                    }
-                },
-            })
-            .flat_map(|t| {
-                t.aliases
-                    .iter()
-                    .map(|a| (a.to_string(), t.clone()))
-                    .chain(once((t.name.clone(), t.clone())))
-                    .collect::<Vec<_>>()
-            })
-            .collect::<Vec<_>>()
+            .map(|d| self.load_tasks_in_dir(&d))
+            .collect::<Result<Vec<_>>>()?
             .into_iter()
+            .flatten()
+            .chain(self.load_global_tasks()?)
+            .chain(self.load_system_tasks()?)
             .rev()
+            .inspect(|t| trace!("loading task {t} from {}", display_path(&t.config_source)))
+            .map(|t| (t.name.clone(), t))
+            .collect())
+    }
+
+    fn load_tasks_in_dir(&self, dir: &Path) -> Result<Vec<Task>> {
+        let configs = self.configs_at_root(dir);
+        let config_tasks = configs.iter().flat_map(|cf| cf.tasks()).cloned();
+        let includes = configs
+            .iter()
+            .find_map(|cf| cf.task_config().includes.clone())
+            .unwrap_or_else(default_task_includes);
+        let file_tasks = includes.into_iter().flat_map(|p| {
+            let p = match p.is_absolute() {
+                true => p,
+                false => dir.join(p),
+            };
+            self.load_tasks_includes(&p).unwrap_or_else(|err| {
+                warn!("loading tasks in {}: {err}", display_path(&p));
+                vec![]
+            })
+        });
+        Ok(file_tasks.into_iter().chain(config_tasks).collect())
+    }
+
+    fn load_global_tasks(&self) -> Result<Vec<Task>> {
+        let cf = self.config_files.get(&*env::MISE_GLOBAL_CONFIG_FILE);
+        Ok(self
+            .load_config_tasks(&cf)
+            .into_iter()
+            .chain(self.load_file_tasks(&cf))
+            .collect())
+    }
+
+    fn load_system_tasks(&self) -> Result<Vec<Task>> {
+        let cf = self.config_files.get(&dirs::SYSTEM.join("config.toml"));
+        Ok(self
+            .load_config_tasks(&cf)
+            .into_iter()
+            .chain(self.load_file_tasks(&cf))
+            .collect())
+    }
+
+    #[allow(clippy::borrowed_box)]
+    fn load_config_tasks(&self, cf: &Option<&Box<dyn ConfigFile>>) -> Vec<Task> {
+        cf.map(|cf| cf.tasks())
+            .unwrap_or_default()
+            .into_iter()
+            .cloned()
+            .collect()
+    }
+
+    #[allow(clippy::borrowed_box)]
+    fn load_file_tasks(&self, cf: &Option<&Box<dyn ConfigFile>>) -> Vec<Task> {
+        let includes = match cf {
+            Some(cf) => cf
+                .task_config()
+                .includes
+                .clone()
+                .unwrap_or(vec!["tasks".into()])
+                .into_iter()
+                .map(|p| cf.get_path().parent().unwrap().join(p))
+                .collect(),
+            None => vec![dirs::CONFIG.join("tasks")],
+        };
+        includes
+            .into_iter()
+            .flat_map(|p| {
+                self.load_tasks_includes(&p).unwrap_or_else(|err| {
+                    warn!("loading tasks in {}: {err}", display_path(&p));
+                    vec![]
+                })
+            })
+            .collect()
+    }
+
+    fn load_tasks_includes(&self, root: &Path) -> Result<Vec<Task>> {
+        file::recursive_ls(root)?
+            .into_iter()
+            .filter(|p| file::is_executable(p))
+            .map(|path| Task::from_path(&path))
+            .collect()
+    }
+
+    fn configs_at_root(&self, dir: &Path) -> Vec<&dyn ConfigFile> {
+        DEFAULT_CONFIG_FILENAMES
+            .iter()
+            .map(|f| dir.join(f))
+            .filter_map(|f| self.config_files.get(&f).map(|cf| cf.as_ref()))
             .collect()
     }
 
@@ -320,12 +378,15 @@ impl Config {
         EnvResults::resolve(&env::PRISTINE_ENV, entries)
     }
 
-    pub fn watch_files(&self) -> eyre::Result<BTreeSet<&Path>> {
+    pub fn watch_files(&self) -> eyre::Result<BTreeSet<PathBuf>> {
+        let env_results = self.env_results()?;
         Ok(self
             .config_files
             .keys()
-            .chain(self.env_results()?.env_files.iter())
-            .map(|p| p.as_path())
+            .map(|p| p.to_path_buf())
+            .chain(env_results.env_files.clone())
+            .chain(env_results.env_scripts.clone())
+            .chain(Settings::get().env_files())
             .collect())
     }
 
@@ -420,13 +481,11 @@ pub fn load_config_paths(config_filenames: &[String]) -> Vec<PathBuf> {
 
     // The current directory is not always available, e.g.
     // when a directory was deleted or inside FUSE mounts.
-    match env::current_dir() {
-        Ok(current_dir) => {
-            config_files.extend(file::FindUp::new(&current_dir, config_filenames));
-        }
-        Err(error) => {
-            debug!("error getting current dir: {error}");
+    match &*dirs::CWD {
+        Some(current_dir) => {
+            config_files.extend(file::FindUp::new(current_dir, config_filenames));
         }
+        None => {}
     };
 
     config_files.extend(global_config_files());
@@ -561,6 +620,10 @@ impl Debug for Config {
     }
 }
 
+fn default_task_includes() -> Vec<PathBuf> {
+    vec![".mise/tasks".into(), ".config/mise/tasks".into()]
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
