@@ -13,8 +13,10 @@ use serde::ser::Error;
 use serde_derive::{Deserialize, Serialize};
 
 use crate::config::{system_config_files, DEFAULT_CONFIG_FILENAMES};
+use crate::file::FindUp;
 use crate::{config, dirs, env, file};
 
+#[rustfmt::skip]
 #[derive(Config, Default, Debug, Clone, Serialize)]
 #[config(partial_attr(derive(Clone, Serialize, Default)))]
 #[config(partial_attr(serde(deny_unknown_fields)))]
@@ -44,6 +46,34 @@ pub struct Settings {
     pub disable_tools: BTreeSet<String>,
     #[config(env = "MISE_EXPERIMENTAL", default = false)]
     pub experimental: bool,
+    /// after installing a go version, run `go install` on packages listed in this file
+    #[config(env = "MISE_GO_DEFAULT_PACKAGES_FILE", default = "~/.default-go-packages")]
+    pub go_default_packages_file: PathBuf,
+    /// url to fetch go sdks from
+    #[config(env = "MISE_GO_DOWNLOAD_MIRROR", default = "https://dl.google.com/go")]
+    pub go_download_mirror: String,
+    /// used for fetching go versions
+    #[config(env = "MISE_GO_REPO", default = "https://github.com/golang/go")]
+    pub go_repo: String,
+    /// changes where `go install` installs binaries to
+    /// defaults to ~/.local/share/mise/installs/go/.../bin
+    /// set to true to override GOBIN if previously set
+    /// set to false to not set GOBIN (default is ${GOPATH:-$HOME/go}/bin)
+    #[config(env = "MISE_GO_SET_GOBIN")]
+    pub go_set_gobin: Option<bool>,
+    /// [deprecated] set to true to set GOPATH=~/.local/share/mise/installs/go/.../packages
+    /// use to make mise behave like asdf but there are no known use-cases where this is necessary.
+    /// See https://github.com/jdx/mise/discussions/1638
+    #[config(env = "MISE_GO_SET_GOPATH", default = false)]
+    pub go_set_gopath: bool,
+    /// sets GOROOT=~/.local/share/mise/installs/go/.../
+    /// you probably always want this set to be set unless you want GOROOT to point to something
+    /// other than the sdk mise is currently set to
+    #[config(env = "MISE_GO_SET_GOROOT", default = true)]
+    pub go_set_goroot: bool,
+    /// set to true to skip checksum verification when downloading go sdk tarballs
+    #[config(env = "MISE_GO_SKIP_CHECKSUM", default = false)]
+    pub go_skip_checksum: bool,
     #[config(env = "MISE_JOBS", default = 4)]
     pub jobs: usize,
     #[config(env = "MISE_LEGACY_VERSION_FILE", default = true)]
@@ -65,18 +95,13 @@ pub struct Settings {
     #[config(env = "MISE_PYTHON_PATCH_URL")]
     pub python_patch_url: Option<String>,
     #[config(env = "MISE_PYTHON_PATCHES_DIRECTORY")]
-    pub python_precompiled_os: Option<String>,
-    #[config(env = "MISE_PYTHON_PRECOMPILED_ARCH")]
     pub python_patches_directory: Option<PathBuf>,
-    #[config(env = "MISE_PYTHON_PRECOMPILED_OS")]
+    #[config(env = "MISE_PYTHON_PRECOMPILED_ARCH")]
     pub python_precompiled_arch: Option<String>,
-    #[config(
-        env = "MISE_PYENV_REPO",
-        default = "https://github.com/pyenv/pyenv.git"
-    )]
+    #[config(env = "MISE_PYTHON_PRECOMPILED_OS")]
+    pub python_precompiled_os: Option<String>,
+    #[config(env = "MISE_PYENV_REPO", default = "https://github.com/pyenv/pyenv.git")]
     pub python_pyenv_repo: String,
-    #[config(env = "MISE_PYTHON_VENV_AUTO_CREATE", default = false)]
-    pub python_venv_auto_create: bool,
     #[config(env = "MISE_RAW", default = false)]
     pub raw: bool,
     #[config(env = "MISE_SHORTHANDS_FILE")]
@@ -99,7 +124,7 @@ pub struct Settings {
     #[config(env = "CI", default = false)]
     pub ci: bool,
     #[config(env = "MISE_CD")]
-    pub cd: Option<String>,
+    pub cd: Option<PathBuf>,
     #[config(env = "MISE_DEBUG", default = false)]
     pub debug: bool,
     #[config(env = "MISE_ENV_FILE")]
@@ -108,6 +133,8 @@ pub struct Settings {
     pub trace: bool,
     #[config(env = "MISE_LOG_LEVEL", default = "info")]
     pub log_level: String,
+    #[config(env = "MISE_PYTHON_VENV_AUTO_CREATE", default = false)]
+    pub python_venv_auto_create: bool,
 }
 
 #[derive(Config, Default, Debug, Clone, Serialize)]
@@ -115,8 +142,11 @@ pub struct Settings {
 #[config(partial_attr(serde(deny_unknown_fields)))]
 pub struct SettingsStatus {
     /// warn if a tool is missing
-    #[config(env = "MISE_STATUS_MESSAGE_MISSING_TOOLS", default = true)]
-    pub missing_tools: bool,
+    #[config(
+        env = "MISE_STATUS_MESSAGE_MISSING_TOOLS",
+        default = "if_other_versions_installed"
+    )]
+    pub missing_tools: SettingsStatusMissingTools,
     /// show env var keys when entering directories
     #[config(env = "MISE_STATUS_MESSAGE_SHOW_ENV", default = false)]
     pub show_env: bool,
@@ -125,6 +155,19 @@ pub struct SettingsStatus {
     pub show_tools: bool,
 }
 
+#[derive(Debug, Clone, Copy, Serialize, Deserialize, Default, EnumString, Display)]
+#[serde(rename_all = "snake_case")]
+#[strum(serialize_all = "snake_case")]
+pub enum SettingsStatusMissingTools {
+    /// never show the warning
+    Never,
+    /// hide this warning if the user hasn't installed at least 1 version of the tool before
+    #[default]
+    IfOtherVersionsInstalled,
+    /// always show the warning if tools are missing
+    Always,
+}
+
 pub type SettingsPartial = <Settings as Config>::Partial;
 
 static SETTINGS: RwLock<Option<Arc<Settings>>> = RwLock::new(None);
@@ -154,21 +197,31 @@ impl Settings {
         if let Some(settings) = SETTINGS.read().unwrap().as_ref() {
             return Ok(settings.clone());
         }
+
+        // Initial pass to obtain cd option
         let mut sb = Self::builder()
             .preloaded(CLI_SETTINGS.lock().unwrap().clone().unwrap_or_default())
             .env();
-        for file in Self::all_settings_files() {
-            sb = sb.preloaded(file);
-        }
-        let mut settings = sb.preloaded(DEFAULT_SETTINGS.clone()).load()?;
-        if let Some(cd) = &settings.cd {
+
+        let mut settings = sb.load()?;
+        if let Some(mut cd) = settings.cd {
             static ORIG_PATH: Lazy<std::io::Result<PathBuf>> = Lazy::new(env::current_dir);
-            let mut cd = PathBuf::from(cd);
             if cd.is_relative() {
                 cd = ORIG_PATH.as_ref()?.join(cd);
             }
             env::set_current_dir(cd)?;
         }
+
+        // Reload settings after current directory option processed
+        sb = Self::builder()
+            .preloaded(CLI_SETTINGS.lock().unwrap().clone().unwrap_or_default())
+            .env();
+        for file in Self::all_settings_files() {
+            sb = sb.preloaded(file);
+        }
+        sb = sb.preloaded(DEFAULT_SETTINGS.clone());
+
+        settings = sb.load()?;
         if settings.raw {
             settings.jobs = 1;
         }
@@ -179,7 +232,7 @@ impl Settings {
             settings.log_level = "trace".to_string();
         }
         if settings.quiet {
-            settings.log_level = "warn".to_string();
+            settings.log_level = "error".to_string();
         }
         if settings.log_level == "trace" || settings.log_level == "debug" {
             settings.verbose = true;
@@ -219,8 +272,8 @@ impl Settings {
                 s.raw = Some(true);
             }
         }
-        if let Some(cd) = m.get_one::<String>("cd") {
-            s.cd = Some(cd.to_string());
+        if let Some(cd) = m.get_one::<PathBuf>("cd") {
+            s.cd = Some(cd.clone());
         }
         if let Some(true) = m.get_one::<bool>("yes") {
             s.yes = Some(true);
@@ -305,10 +358,20 @@ impl Settings {
         Ok(settings)
     }
 
-    pub fn hidden_configs() -> HashSet<&'static str> {
-        static HIDDEN_CONFIGS: Lazy<HashSet<&'static str>> =
-            Lazy::new(|| ["ci", "cd", "debug", "env_file", "trace", "log_level"].into());
-        HIDDEN_CONFIGS.clone()
+    pub fn hidden_configs() -> &'static HashSet<&'static str> {
+        static HIDDEN_CONFIGS: Lazy<HashSet<&'static str>> = Lazy::new(|| {
+            [
+                "ci",
+                "cd",
+                "debug",
+                "env_file",
+                "trace",
+                "log_level",
+                "python_venv_auto_create",
+            ]
+            .into()
+        });
+        &HIDDEN_CONFIGS
     }
 
     pub fn reset(cli_settings: Option<SettingsPartial>) {
@@ -316,10 +379,10 @@ impl Settings {
         *SETTINGS.write().unwrap() = None;
     }
 
-    pub fn ensure_experimental(&self) -> Result<()> {
-        let msg =
-            "This command is experimental. Enable it with `mise settings set experimental true`";
-        ensure!(self.experimental, msg);
+    pub fn ensure_experimental(&self, what: &str) -> Result<()> {
+        if !self.experimental {
+            bail!("{what} is experimental. Enable it with `mise settings set experimental true`");
+        }
         Ok(())
     }
 
@@ -338,13 +401,30 @@ impl Settings {
                 }
             })
     }
+
+    pub fn env_files(&self) -> Vec<PathBuf> {
+        let mut files = vec![];
+        if let Some(cwd) = &*dirs::CWD {
+            if let Some(env_file) = &self.env_file {
+                let env_file = env_file.to_string_lossy().to_string();
+                for p in FindUp::new(cwd, &[env_file]) {
+                    files.push(p);
+                }
+            }
+        }
+        files.into_iter().rev().collect()
+    }
+
+    pub fn as_dict(&self) -> eyre::Result<toml::Table> {
+        Ok(self.to_string().parse()?)
+    }
 }
 
 impl Display for Settings {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        match serde_json::to_string_pretty(self) {
+        match toml::to_string_pretty(self) {
             Ok(s) => write!(f, "{}", s),
-            Err(e) => std::fmt::Result::Err(std::fmt::Error::custom(e)),
+            Err(e) => Err(std::fmt::Error::custom(e)),
         }
     }
 }
