@@ -73,6 +73,8 @@ pub static MISE_FETCH_REMOTE_VERSIONS_TIMEOUT: Lazy<Duration> = Lazy::new(|| {
     var_duration("MISE_FETCH_REMOTE_VERSIONS_TIMEOUT").unwrap_or(Duration::from_secs(10))
 });
 
+pub static __USAGE: Lazy<Option<String>> = Lazy::new(|| var("__USAGE").ok());
+
 #[cfg(test)]
 pub static TERM_WIDTH: Lazy<usize> = Lazy::new(|| 80);
 
@@ -113,7 +115,6 @@ pub static __MISE_WATCH: Lazy<Option<HookEnvWatches>> = Lazy::new(|| match var("
         .ok(),
     _ => None,
 });
-pub static CI: Lazy<bool> = Lazy::new(|| var_is_true("CI"));
 pub static LINUX_DISTRO: Lazy<Option<String>> = Lazy::new(linux_distro);
 pub static PREFER_STALE: Lazy<bool> = Lazy::new(|| prefer_stale(&ARGS.read().unwrap()));
 /// essentially, this is whether we show spinners or build output on runtime install
@@ -219,21 +220,6 @@ pub static MISE_RUBY_DEFAULT_PACKAGES_FILE: Lazy<PathBuf> = Lazy::new(|| {
     var_path("MISE_RUBY_DEFAULT_PACKAGES_FILE").unwrap_or_else(|| HOME.join(".default-gems"))
 });
 
-// go
-pub static MISE_GO_DEFAULT_PACKAGES_FILE: Lazy<PathBuf> = Lazy::new(|| {
-    var_path("MISE_GO_DEFAULT_PACKAGES_FILE").unwrap_or_else(|| HOME.join(".default-go-packages"))
-});
-pub static MISE_GO_SKIP_CHECKSUM: Lazy<bool> = Lazy::new(|| var_is_true("MISE_GO_SKIP_CHECKSUM"));
-pub static MISE_GO_REPO: Lazy<String> =
-    Lazy::new(|| var("MISE_GO_REPO").unwrap_or_else(|_| "https://github.com/golang/go".into()));
-pub static MISE_GO_DOWNLOAD_MIRROR: Lazy<String> = Lazy::new(|| {
-    var("MISE_GO_DOWNLOAD_MIRROR").unwrap_or_else(|_| "https://dl.google.com/go".into())
-});
-pub static MISE_GO_SET_GOROOT: Lazy<Option<bool>> =
-    Lazy::new(|| var_option_bool("MISE_GO_SET_GOROOT"));
-pub static MISE_GO_SET_GOPATH: Lazy<Option<bool>> =
-    Lazy::new(|| var_option_bool("MISE_GO_SET_GOPATH"));
-
 fn get_env_diff() -> EnvDiff {
     let env = vars().collect::<HashMap<_, _>>();
     match env.get("__MISE_DIFF") {
@@ -375,13 +361,12 @@ fn is_ninja_on_path() -> bool {
     which::which("ninja").is_ok()
 }
 
+pub fn is_activated() -> bool {
+    var("__MISE_DIFF").is_ok()
+}
+
 #[cfg(test)]
 mod tests {
-    use std::collections::HashMap;
-
-    use crate::env::apply_patches;
-    use crate::env_diff::EnvDiffOperation;
-
     use super::*;
 
     #[test]
