@@ -105,8 +105,9 @@ pub fn basename(path: &Path) -> Option<String> {
 }
 
 /// replaces $HOME with "~"
-pub fn display_path(path: &Path) -> String {
+pub fn display_path<P: AsRef<Path>>(path: P) -> String {
     let home = dirs::HOME.to_string_lossy();
+    let path = path.as_ref();
     match path.starts_with(home.as_ref()) && home != "/" {
         true => path.to_string_lossy().replacen(home.as_ref(), "~", 1),
         false => path.to_string_lossy().to_string(),
@@ -240,6 +241,16 @@ pub fn make_executable(path: &Path) -> Result<()> {
     Ok(())
 }
 
+pub fn all_dirs() -> Result<Vec<PathBuf>> {
+    let mut output = vec![];
+    let mut cwd = dirs::CWD.as_ref().map(|p| p.as_path());
+    while let Some(dir) = cwd {
+        output.push(dir.to_path_buf());
+        cwd = dir.parent();
+    }
+    Ok(output)
+}
+
 fn is_empty_dir(path: &Path) -> Result<bool> {
     path.read_dir()
         .map(|mut i| i.next().is_none())
@@ -273,7 +284,7 @@ impl Iterator for FindUp {
                 return Some(path);
             }
         }
-        self.current_dir_filenames = self.filenames.clone();
+        self.current_dir_filenames.clone_from(&self.filenames);
         if cfg!(test) && self.current_dir == *dirs::HOME {
             return None; // in tests, do not recurse further than ./test
         }
@@ -289,11 +300,13 @@ impl Iterator for FindUp {
 pub fn which<P: AsRef<Path>>(name: P) -> Option<PathBuf> {
     _which(name, &env::PATH)
 }
+
 /// returns the first executable in PATH
 /// will include mise bin paths or other paths added by mise
 pub fn which_non_pristine<P: AsRef<Path>>(name: P) -> Option<PathBuf> {
     _which(name, &env::PATH_NON_PRISTINE)
 }
+
 fn _which<P: AsRef<Path>>(name: P, paths: &Vec<PathBuf>) -> Option<PathBuf> {
     for path in paths {
         let bin = path.join(name.as_ref());
@@ -326,10 +339,6 @@ pub fn unzip(archive: &Path, dest: &Path) -> Result<()> {
 mod tests {
     use std::ops::Deref;
 
-    use itertools::Itertools;
-
-    use crate::dirs;
-
     use super::*;
 
     #[test]
@@ -366,7 +375,7 @@ mod tests {
     #[test]
     fn test_display_path() {
         let path = dirs::HOME.join("cwd");
-        assert_eq!(display_path(&path), "~/cwd");
+        assert_eq!(display_path(path), "~/cwd");
 
         let path = Path::new("/tmp")
             .join(dirs::HOME.deref().strip_prefix("/").unwrap())
