@@ -2,6 +2,7 @@ use std::collections::hash_map::DefaultHasher;
 use std::collections::HashMap;
 use std::fs::File;
 use std::hash::{Hash, Hasher};
+use std::io::{Read, Write};
 use std::path::Path;
 
 use eyre::Result;
@@ -9,6 +10,7 @@ use rayon::prelude::*;
 use sha2::{Digest, Sha256};
 
 use crate::file::display_path;
+use crate::ui::progress_report::SingleReport;
 
 pub fn hash_to_str<T: Hash>(t: &T) -> String {
     let mut s = DefaultHasher::new();
@@ -18,15 +20,37 @@ pub fn hash_to_str<T: Hash>(t: &T) -> String {
 }
 
 pub fn file_hash_sha256(path: &Path) -> Result<String> {
+    file_hash_sha256_prog(path, None)
+}
+
+pub fn file_hash_sha256_prog(path: &Path, pr: Option<&dyn SingleReport>) -> Result<String> {
     let mut file = File::open(path)?;
+    if let Some(pr) = pr {
+        pr.set_length(file.metadata()?.len());
+    }
     let mut hasher = Sha256::new();
+    let mut buf = [0; 32 * 1024];
+    loop {
+        let n = file.read(&mut buf)?;
+        if n == 0 {
+            break;
+        }
+        hasher.write_all(&buf[..n])?;
+        if let Some(pr) = pr {
+            pr.inc(n as u64);
+        }
+    }
     std::io::copy(&mut file, &mut hasher)?;
     let hash = hasher.finalize();
     Ok(format!("{hash:x}"))
 }
 
-pub fn ensure_checksum_sha256(path: &Path, checksum: &str) -> Result<()> {
-    let actual = file_hash_sha256(path)?;
+pub fn ensure_checksum_sha256(
+    path: &Path,
+    checksum: &str,
+    pr: Option<&dyn SingleReport>,
+) -> Result<()> {
+    let actual = file_hash_sha256_prog(path, pr)?;
     ensure!(
         actual == checksum,
         "Checksum mismatch for file {}:\nExpected: {checksum}\nActual:   {actual}",
