@@ -1,4 +1,5 @@
 use std::fs::File;
+use std::io::{Read, Write};
 use std::path::Path;
 use std::time::Duration;
 
@@ -10,6 +11,7 @@ use reqwest::IntoUrl;
 use crate::cli::version;
 use crate::env::MISE_FETCH_REMOTE_VERSIONS_TIMEOUT;
 use crate::file::display_path;
+use crate::ui::progress_report::SingleReport;
 use crate::{env, file};
 
 #[cfg(not(test))]
@@ -43,7 +45,7 @@ impl Client {
     }
 
     pub fn get<U: IntoUrl>(&self, url: U) -> Result<Response> {
-        let url = url.into_url().unwrap();
+        let mut url = url.into_url().unwrap();
         debug!("GET {}", url);
         let mut req = self.reqwest.get(url.clone());
         if url.host_str() == Some("api.github.com") {
@@ -51,17 +53,37 @@ impl Client {
                 req = req.header("authorization", format!("token {}", token));
             }
         }
-        let resp = req.send()?;
+
+        let resp = match req.send() {
+            Ok(resp) => resp,
+            Err(_) if url.scheme() == "http" => {
+                // try with https since http may be blocked
+                url.set_scheme("https").unwrap();
+                return self.get(url);
+            }
+            Err(err) => return Err(err.into()),
+        };
+
         debug!("GET {url} {}", resp.status());
+        if url.scheme() == "http" && resp.error_for_status_ref().is_err() {
+            // try with https since http may be blocked
+            url.set_scheme("https").unwrap();
+            return self.get(url);
+        }
         resp.error_for_status_ref()?;
         Ok(resp)
     }
 
     pub fn get_text<U: IntoUrl>(&self, url: U) -> Result<String> {
-        let url = url.into_url().unwrap();
+        let mut url = url.into_url().unwrap();
         let resp = self.get(url.clone())?;
         let text = resp.text()?;
         if text.starts_with("<!DOCTYPE html>") {
+            if url.scheme() == "http" {
+                // try with https since http may be blocked
+                url.set_scheme("https").unwrap();
+                return self.get_text(url);
+            }
             bail!("Got HTML instead of text from {}", url);
         }
         Ok(text)
@@ -77,14 +99,35 @@ impl Client {
         Ok(json)
     }
 
-    pub fn download_file<U: IntoUrl>(&self, url: U, path: &Path) -> Result<()> {
+    pub fn download_file<U: IntoUrl>(
+        &self,
+        url: U,
+        path: &Path,
+        pr: Option<&dyn SingleReport>,
+    ) -> Result<()> {
         let url = url.into_url()?;
         debug!("GET Downloading {} to {}", &url, display_path(path));
         let mut resp = self.get(url)?;
+        if let Some(length) = resp.content_length() {
+            if let Some(pr) = pr {
+                pr.set_length(length);
+            }
+        }
 
         file::create_dir_all(path.parent().unwrap())?;
+
+        let mut buf = [0; 32 * 1024];
         let mut file = File::create(path)?;
-        resp.copy_to(&mut file)?;
+        loop {
+            let n = resp.read(&mut buf)?;
+            if n == 0 {
+                break;
+            }
+            file.write_all(&buf[..n])?;
+            if let Some(pr) = pr {
+                pr.inc(n as u64);
+            }
+        }
         Ok(())
     }
 }
