@@ -120,10 +120,6 @@ impl PythonPlugin {
     }
 
     fn install_precompiled(&self, ctx: &InstallContext) -> Result<()> {
-        warn!("installing precompiled python from indygreg/python-build-standalone");
-        warn!("if you experience issues with this python, switch to python-build");
-        warn!("by running: mise settings set python_compile 1");
-
         let precompile_info = self
             .fetch_precompiled_remote_versions()?
             .iter()
@@ -133,6 +129,11 @@ impl PythonPlugin {
             Some((_, tag, filename)) => (tag, filename),
             None => return self.install_compiled(ctx),
         };
+
+        warn!("installing precompiled python from indygreg/python-build-standalone");
+        warn!("if you experience issues with this python, switch to python-build");
+        warn!("by running: mise settings set python_compile 1");
+
         let url = format!(
             "https://github.com/indygreg/python-build-standalone/releases/download/{tag}/{filename}"
         );
@@ -141,11 +142,10 @@ impl PythonPlugin {
         let download = ctx.tv.download_path();
         let tarball_path = download.join(filename);
 
-        ctx.pr.set_message(format!("downloading {}", &url));
-        HTTP.download_file(&url, &tarball_path)?;
+        ctx.pr.set_message(format!("downloading {filename}"));
+        HTTP.download_file(&url, &tarball_path, Some(ctx.pr.as_ref()))?;
 
-        ctx.pr
-            .set_message(format!("installing {}", tarball_path.display()));
+        ctx.pr.set_message(format!("installing {filename}"));
         file::untar(&tarball_path, &download)?;
         file::remove_all(&install)?;
         file::rename(download.join("python"), &install)?;
@@ -165,6 +165,7 @@ impl PythonPlugin {
             .with_pr(ctx.pr.as_ref())
             .arg(ctx.tv.version.as_str())
             .arg(&ctx.tv.install_path())
+            .env("PIP_REQUIRE_VIRTUALENV", "false")
             .envs(config.env()?);
         if settings.verbose {
             cmd = cmd.arg("--verbose");
@@ -209,6 +210,7 @@ impl PythonPlugin {
             .arg("--upgrade")
             .arg("-r")
             .arg(packages_file)
+            .env("PIP_REQUIRE_VIRTUALENV", "false")
             .envs(config.env()?)
             .execute()
     }
@@ -249,8 +251,6 @@ impl PythonPlugin {
                 } else {
                     warn!(
                         "no venv found at: {p}\n\n\
-                        To have mise automatically create virtualenvs, run:\n\
-                        mise settings set python_venv_auto_create true\n\n\
                         To create a virtualenv manually, run:\n\
                         python -m venv {p}",
                         p = display_path(&virtualenv)
@@ -283,6 +283,7 @@ impl PythonPlugin {
     fn test_python(&self, config: &Config, tv: &ToolVersion, pr: &dyn SingleReport) -> Result<()> {
         pr.set_message("python --version".into());
         CmdLineRunner::new(self.python_path(tv))
+            .with_pr(pr)
             .arg("--version")
             .envs(config.env()?)
             .execute()
@@ -368,7 +369,7 @@ fn python_arch(settings: &Settings) -> &str {
         } else if cfg!(target_feature = "sse4.1") {
             "x86_64_v2"
         } else {
-            "x86_64_v1"
+            "x86_64"
         }
     } else {
         built_info::CFG_TARGET_ARCH
