@@ -180,7 +180,7 @@ impl ExternalPlugin {
         )
         .wrap_err_with(|| {
             let script = self.script_man.get_script_path(&Script::ListAll);
-            eyre!("Failed to run {}", display_path(&script))
+            eyre!("Failed to run {}", display_path(script))
         })?;
         let stdout = String::from_utf8(result.stdout).unwrap();
         let stderr = String::from_utf8(result.stderr).unwrap().trim().to_string();
@@ -444,6 +444,16 @@ impl Forge for ExternalPlugin {
     fn get_plugin_type(&self) -> PluginType {
         PluginType::External
     }
+
+    fn get_dependencies(&self, tv: &ToolVersion) -> Result<Vec<String>> {
+        let out = match tv.forge.name.as_str() {
+            "poetry" | "pipenv" => vec!["python"],
+            "elixir" => vec!["erlang"],
+            _ => vec![],
+        };
+        Ok(out.into_iter().map(|s| s.into()).collect())
+    }
+
     fn list_remote_versions(&self) -> Result<Vec<String>> {
         self.remote_version_cache
             .get_or_try_init(|| self.fetch_remote_versions())
@@ -528,7 +538,7 @@ impl Forge for ExternalPlugin {
         let plugin_path = self.plugin_path.to_path_buf();
         if plugin_path.is_symlink() {
             warn!(
-                "Plugin: {} is a symlink, not updating",
+                "plugin:{} is a symlink, not updating",
                 style(&self.name).blue().for_stderr()
             );
             return Ok(());
@@ -536,7 +546,7 @@ impl Forge for ExternalPlugin {
         let git = Git::new(plugin_path);
         if !git.is_repo() {
             warn!(
-                "Plugin {} is not a git repository, not updating",
+                "plugin:{} is not a git repository, not updating",
                 style(&self.name).blue().for_stderr()
             );
             return Ok(());
