@@ -2,7 +2,7 @@ use std::path::Path;
 
 use color_eyre::eyre::eyre;
 use color_eyre::{Result, Section};
-use toml_edit::{Document, Item, Value};
+use toml_edit::{DocumentMut, Item, Value};
 
 use crate::{file, parse_error};
 
@@ -39,7 +39,7 @@ impl MisePluginToml {
     }
 
     fn parse(&mut self, s: &str) -> Result<()> {
-        let doc: Document = s.parse().suggestion("ensure file is valid TOML")?;
+        let doc: DocumentMut = s.parse().suggestion("ensure file is valid TOML")?;
         for (k, v) in doc.iter() {
             match k {
                 "exec-env" => self.exec_env = self.parse_script_config(k, v)?,
