@@ -3,7 +3,6 @@ use std::collections::HashSet;
 use clap::Command;
 use once_cell::sync::Lazy;
 
-mod fish_complete;
 mod zsh_complete;
 
 pub fn zsh_complete(cmd: &Command) -> eyre::Result<String> {
@@ -12,15 +11,7 @@ pub fn zsh_complete(cmd: &Command) -> eyre::Result<String> {
     Ok(output)
 }
 
-pub fn fish_complete(cmd: &Command) -> eyre::Result<String> {
-    let output = fish_complete::render(cmd);
-    // eprintln!("{}", output);
-    // let result = cmd!("shfmt", "-s").stdin_bytes(output).read()?;
-    Ok(output)
-}
-
-static BANNED_COMMANDS: Lazy<HashSet<&str>> =
-    Lazy::new(|| ["render-mangen", "render-help", "render-completion"].into());
+static BANNED_COMMANDS: Lazy<HashSet<&str>> = Lazy::new(|| ["render-mangen", "render-help"].into());
 
 pub fn is_banned(cmd: &Command) -> bool {
     BANNED_COMMANDS.contains(&cmd.get_name())
