@@ -1,5 +1,5 @@
 use std::fmt::{Display, Formatter};
-use std::path::{Path, PathBuf};
+use std::path::Path;
 
 use crate::env;
 
@@ -9,7 +9,6 @@ mod nushell;
 mod xonsh;
 mod zsh;
 
-#[cfg(feature = "clap_complete")]
 pub mod completions;
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, clap::ValueEnum)]
@@ -54,17 +53,9 @@ impl Display for ShellType {
 
 pub trait Shell {
     fn activate(&self, exe: &Path, flags: String) -> String;
-    fn prepend_path(&self, paths: &[PathBuf]) -> String {
-        let mut path = env::var("PATH").unwrap_or_default();
-        for p in paths {
-            if is_dir_not_in_nix(p) && !is_dir_in_path(p) && !p.is_relative() {
-                path = format!("{}:{path}", p.display());
-            }
-        }
-        self.set_env("PATH", &path)
-    }
     fn deactivate(&self) -> String;
     fn set_env(&self, k: &str, v: &str) -> String;
+    fn prepend_env(&self, k: &str, v: &str) -> String;
     fn unset_env(&self, k: &str) -> String;
 }
 
@@ -78,17 +69,3 @@ pub fn get_shell(shell: Option<ShellType>) -> Option<Box<dyn Shell>> {
         _ => None,
     }
 }
-
-pub fn is_dir_in_path(dir: &Path) -> bool {
-    let dir = dir.canonicalize().unwrap_or(dir.to_path_buf());
-    env::PATH
-        .clone()
-        .into_iter()
-        .any(|p| p.canonicalize().unwrap_or(p) == dir)
-}
-
-pub fn is_dir_not_in_nix(dir: &Path) -> bool {
-    !dir.canonicalize()
-        .unwrap_or(dir.to_path_buf())
-        .starts_with("/nix/")
-}
