@@ -24,11 +24,12 @@ use crate::{fake_asdf, forge};
 pub fn handle_shim() -> Result<()> {
     // TODO: instead, check if bin is in shims dir
     let bin_name = *env::MISE_BIN_NAME;
-    if bin_name == "mise" || !dirs::SHIMS.join(bin_name).exists() || cfg!(test) {
+    if regex!(r"^(mise|rtx)(\-.*)?$").is_match(bin_name) || cfg!(test) {
         return Ok(());
     }
     logger::init();
     let args = env::ARGS.read().unwrap();
+    trace!("shim[{bin_name}] args: {}", args.join(" "));
     let mut args: Vec<OsString> = args.iter().map(OsString::from).collect();
     args[0] = which_shim(&env::MISE_BIN_NAME)?.into();
     let exec = Exec {
@@ -47,6 +48,10 @@ fn which_shim(bin_name: &str) -> Result<PathBuf> {
     let mut ts = ToolsetBuilder::new().build(&config)?;
     if let Some((p, tv)) = ts.which(bin_name) {
         if let Some(bin) = p.which(&tv, bin_name)? {
+            trace!(
+                "shim[{bin_name}] ToolVersion: {tv} bin: {bin}",
+                bin = display_path(&bin)
+            );
             return Ok(bin);
         }
     }
@@ -55,6 +60,10 @@ fn which_shim(bin_name: &str) -> Result<PathBuf> {
         for tv in ts.install_missing_bin(bin_name)?.unwrap_or_default() {
             let p = tv.get_forge();
             if let Some(bin) = p.which(&tv, bin_name)? {
+                trace!(
+                    "shim[{bin_name}] NOT_FOUND ToolVersion: {tv} bin: {bin}",
+                    bin = display_path(&bin)
+                );
                 return Ok(bin);
             }
         }
@@ -68,6 +77,7 @@ fn which_shim(bin_name: &str) -> Result<PathBuf> {
         }
         let bin = path.join(bin_name);
         if bin.exists() {
+            trace!("shim[{bin_name}] SYSTEM {bin}", bin = display_path(&bin));
             return Ok(bin);
         }
     }
@@ -143,10 +153,9 @@ fn get_actual_shims(mise_bin: impl AsRef<Path>) -> Result<HashSet<String>> {
     Ok(list_executables_in_dir(&dirs::SHIMS)?
         .into_par_iter()
         .filter(|bin| {
-            dirs::SHIMS
-                .join(bin)
-                .read_link()
-                .is_ok_and(|p| p == mise_bin)
+            let path = dirs::SHIMS.join(bin);
+
+            !path.is_symlink() || path.read_link().is_ok_and(|p| p == mise_bin)
         })
         .collect::<HashSet<_>>())
 }
