@@ -3,6 +3,8 @@ use std::fmt::{Display, Formatter};
 use std::path::PathBuf;
 use std::sync::{Arc, Mutex};
 use std::thread;
+use std::thread::sleep;
+use std::time::Duration;
 
 use console::truncate_str;
 use eyre::Result;
@@ -17,6 +19,7 @@ pub use tool_version_list::ToolVersionList;
 pub use tool_version_request::ToolVersionRequest;
 
 use crate::cli::args::ForgeArg;
+use crate::config::settings::SettingsStatusMissingTools;
 use crate::config::{Config, Settings};
 use crate::env::TERM_WIDTH;
 use crate::forge::Forge;
@@ -84,16 +87,16 @@ impl Toolset {
             .or_insert_with(|| ToolVersionList::new(fa.clone(), self.source.clone().unwrap()));
         tvl.requests.push((tvr, opts));
     }
-    pub fn merge(&mut self, other: &Toolset) {
-        let mut versions = other.versions.clone();
+    pub fn merge(&mut self, other: Toolset) {
+        let mut versions = other.versions;
         for (plugin, tvl) in self.versions.clone() {
-            if !other.versions.contains_key(&plugin) {
+            if !versions.contains_key(&plugin) {
                 versions.insert(plugin, tvl);
             }
         }
         versions.retain(|_, tvl| !self.disable_tools.contains(&tvl.forge));
         self.versions = versions;
-        self.source = other.source.clone();
+        self.source = other.source;
     }
     pub fn resolve(&mut self) {
         self.list_missing_plugins();
@@ -137,6 +140,7 @@ impl Toolset {
         let settings = Settings::try_get()?;
         let queue: Vec<_> = versions
             .into_iter()
+            .rev()
             .group_by(|v| v.forge.clone())
             .into_iter()
             .map(|(fa, v)| (forge::get(&fa), v.collect_vec()))
@@ -152,15 +156,28 @@ impl Toolset {
             true => 1,
             false => opts.jobs.unwrap_or(settings.jobs),
         };
+        let installing: HashSet<String> = HashSet::new();
+        let installing = Arc::new(Mutex::new(installing));
         thread::scope(|s| {
             (0..jobs)
                 .map(|_| {
                     let queue = queue.clone();
+                    let installing = installing.clone();
                     let ts = &*self;
                     s.spawn(move || {
                         let next_job = || queue.lock().unwrap().pop();
                         while let Some((t, versions)) = next_job() {
+                            installing.lock().unwrap().insert(t.id().into());
                             for tv in versions {
+                                for dep in t.get_dependencies(&tv)? {
+                                    while installing.lock().unwrap().contains(dep.as_str()) {
+                                        trace!(
+                                            "{tv} waiting for dependency {} to finish installing",
+                                            dep
+                                        );
+                                        sleep(Duration::from_millis(100));
+                                    }
+                                }
                                 let tv = tv.request.resolve(
                                     t.as_ref(),
                                     tv.opts.clone(),
@@ -175,6 +192,7 @@ impl Toolset {
                                 };
                                 t.install_version(ctx)?;
                             }
+                            installing.lock().unwrap().remove(t.id());
                         }
                         Ok(())
                     })
@@ -293,6 +311,7 @@ impl Toolset {
         let entries = self
             .list_current_installed_versions()
             .into_par_iter()
+            .filter(|(_, tv)| !matches!(tv.request, ToolVersionRequest::System(_)))
             .flat_map(|(p, tv)| match p.exec_env(config, self, &tv) {
                 Ok(env) => env.into_iter().collect(),
                 Err(e) => {
@@ -323,6 +342,7 @@ impl Toolset {
     pub fn list_paths(&self) -> Vec<PathBuf> {
         self.list_current_installed_versions()
             .into_par_iter()
+            .filter(|(_, tv)| !matches!(tv.request, ToolVersionRequest::System(_)))
             .flat_map(|(p, tv)| {
                 p.list_bin_paths(&tv).unwrap_or_else(|e| {
                     warn!("Error listing bin paths for {tv}: {e:#}");
@@ -385,9 +405,23 @@ impl Toolset {
             .collect())
     }
 
+    // shows a warning if any versions are missing
+    // only displays for tools which have at least one version already installed
     pub fn notify_if_versions_missing(&self) {
-        let missing = self.list_missing_versions();
-        if missing.is_empty() || !Settings::get().status.missing_tools {
+        let settings = Settings::get();
+        let missing = self
+            .list_missing_versions()
+            .into_iter()
+            .filter(|tv| match settings.status.missing_tools {
+                SettingsStatusMissingTools::Never => false,
+                SettingsStatusMissingTools::Always => true,
+                SettingsStatusMissingTools::IfOtherVersionsInstalled => tv
+                    .get_forge()
+                    .list_installed_versions()
+                    .is_ok_and(|f| !f.is_empty()),
+            })
+            .collect_vec();
+        if missing.is_empty() {
             return;
         }
         let versions = missing
